@@ -78,6 +78,7 @@ HEADERS_INIT_CONVER = {
     "upgrade-insecure-requests": "1",
     "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36 Edg/110.0.1587.69",
     "x-edge-shopping-flag": "1",
+    "x-forwarded-for": "1.1.1.1",
 }
 
 ssl_context = ssl.create_default_context()
@@ -214,12 +215,18 @@ class Conversation:
 
         # Send GET request
         response = self.session.get(
-            "https://edgeservices.bing.com/edgesvc/turing/conversation/create"
+            url=os.environ.get("BING_PROXY_URL")
+            or "https://edgeservices.bing.com/edgesvc/turing/conversation/create"
         )
         if response.status_code != 200:
-            print(f"Status code: {response.status_code}")
-            print(response.text)
-            raise Exception("Authentication failed")
+            response = self.session.get(
+                "https://edge.churchless.tech/edgesvc/turing/conversation/create"
+            )
+            if response.status_code != 200:
+                print(f"Status code: {response.status_code}")
+                print(response.text)
+                print(response.url)
+                raise Exception("Authentication failed")
         try:
             self.struct = response.json()
             if self.struct["result"]["value"] == "UnauthorizedRequest":
@@ -249,6 +256,7 @@ class ChatHub:
     async def ask_stream(
         self,
         prompt: str,
+        wss_link: str,
         conversation_style: CONVERSATION_STYLE_TYPE = None,
     ) -> Generator[str, None, None]:
         """
@@ -259,7 +267,7 @@ class ChatHub:
                 await self.wss.close()
         # Check if websocket is closed
         self.wss = await websockets.connect(
-            "wss://sydney.bing.com/sydney/ChatHub",
+            wss_link,
             extra_headers=HEADERS,
             max_size=None,
             ssl=ssl_context,
@@ -320,6 +328,7 @@ class Chatbot:
     async def ask(
         self,
         prompt: str,
+        wss_link: str = "wss://sydney.bing.com/sydney/ChatHub",
         conversation_style: CONVERSATION_STYLE_TYPE = None,
     ) -> dict:
         """
@@ -328,6 +337,7 @@ class Chatbot:
         async for final, response in self.chat_hub.ask_stream(
             prompt=prompt,
             conversation_style=conversation_style,
+            wss_link=wss_link
         ):
             if final:
                 return response
@@ -336,6 +346,7 @@ class Chatbot:
     async def ask_stream(
         self,
         prompt: str,
+        wss_link: str = "wss://sydney.bing.com/sydney/ChatHub",
         conversation_style: CONVERSATION_STYLE_TYPE = None,
     ) -> Generator[str, None, None]:
         """
@@ -344,6 +355,7 @@ class Chatbot:
         async for response in self.chat_hub.ask_stream(
             prompt=prompt,
             conversation_style=conversation_style,
+            wss_link=wss_link
         ):
             yield response
 
@@ -411,7 +423,7 @@ async def main():
         print("Bot:")
         if args.no_stream:
             print(
-                (await bot.ask(prompt=question, conversation_style=args.style))["item"][
+                (await bot.ask(prompt=question, conversation_style=args.style,wss_link=args.wss_link))["item"][
                     "messages"
                 ][1]["adaptiveCards"][0]["body"][0]["text"],
             )
@@ -423,6 +435,7 @@ async def main():
                     async for final, response in bot.ask_stream(
                         prompt=question,
                         conversation_style=args.style,
+                        wss_link=args.wss_link
                     ):
                         if not final:
                             if wrote > len(response):
@@ -436,6 +449,7 @@ async def main():
                 async for final, response in bot.ask_stream(
                     prompt=question,
                     conversation_style=args.style,
+                    wss_link=args.wss_link
                 ):
                     if not final:
                         print(response[wrote:], end="", flush=True)
@@ -463,6 +477,9 @@ if __name__ == "__main__":
     parser.add_argument(
         "--proxy", help="Proxy URL (e.g. socks5://127.0.0.1:1080)", type=str
     )
+    parser.add_argument(
+        "--wss-link", help="WSS URL(e.g. wss://sydney.bing.com/sydney/ChatHub)",type=str,default="wss://sydney.bing.com/sydney/ChatHub"
+    )
     parser.add_argument(
         "--style",
         choices=["creative", "balanced", "precise"],
